@@ -6,7 +6,7 @@ from sqlalchemy.sql import func
 from sqlalchemy.dialects.mysql import TINYINT
 from marshmallow import fields
 from marshmallow import Schema
-from marshmallow import post_dump
+from marshmallow import post_load
 
 from .base import Base
 
@@ -37,10 +37,6 @@ class UserSchema(Schema):
     activation_date = fields.DateTime(data_key='activationDate')
     updated_date = fields.DateTime(data_key='updatedDate')
 
-    @post_dump
-    def map_keys(self, data, **kwargs):
-        return {
-            "registrationDate": data["registration_date"],
-            "activationDate": data["activation_date"],
-            "updatedDate": data["updated_date"],
-        }
+    @post_load
+    def make_address(self, data, **kwargs):
+        return User(**data)
